@@ -41,23 +41,27 @@ class GraphMail:
         response = request.json()
         return response
 
-    def getMailBySearch(self, _search, _emailBox, folder=None):
+    def getMailBySearch(self, _search, _emailBox, _folder=None, _select=None):
         url = f"{self._baseUrl}/v1.0/users/{_emailBox}/messages"
         headers = {"Authorization": f"Bearer {self.accessToken}"}
         params = {}
+        _folderId = None
         if _search:
-            params = {
-                "search": _search,
-            }
-        if folder:
+            params["$search"] = _search
+
+        if _select:
+            params["$select"] = _select
+
+        if _folder:
             data = self.getMailFolders(_emailBox)
 
             for folders in data["value"]:
-                if folders["displayName"] == folder:
+                if folders["displayName"] == _folder:
                     _folderId = folders["id"]
                     break
 
-            # TODO - Add error handling if folder not found
+            if not _folderId:
+                return {"statusCode": 404, "message": "Folder not found"}
 
             url = f"{self._baseUrl}/v1.0/users/{_emailBox}/mailFolders/{_folderId}/messages"
 
